@@ -21,6 +21,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import ros_cdk_assembly_schema
@@ -49,6 +51,18 @@ class AliyunRosStackProperties:
         :param parameters: Values for ROS stack parameters that should be passed when the stack is deployed.
         :param stack_name: The name to use for the ROS stack. Default: - name derived from artifact ID
         '''
+        if __debug__:
+            def stub(
+                *,
+                template_file: builtins.str,
+                parameters: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+                stack_name: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument template_file", value=template_file, expected_type=type_hints["template_file"])
+            check_type(argname="argument parameters", value=parameters, expected_type=type_hints["parameters"])
+            check_type(argname="argument stack_name", value=stack_name, expected_type=type_hints["stack_name"])
         self._values: typing.Dict[str, typing.Any] = {
             "template_file": template_file,
         }
@@ -97,12 +111,24 @@ class AliyunRosStackProperties:
     name_mapping={"runtime_info": "runtimeInfo"},
 )
 class AssemblyBuildOptions:
-    def __init__(self, *, runtime_info: typing.Optional["RuntimeInfo"] = None) -> None:
+    def __init__(
+        self,
+        *,
+        runtime_info: typing.Optional[typing.Union["RuntimeInfo", typing.Dict[str, typing.Any]]] = None,
+    ) -> None:
         '''
         :param runtime_info: Include the specified runtime information (module versions) in manifest. Default: - if this option is not specified, runtime info will not be included
         '''
         if isinstance(runtime_info, dict):
             runtime_info = RuntimeInfo(**runtime_info)
+        if __debug__:
+            def stub(
+                *,
+                runtime_info: typing.Optional[typing.Union["RuntimeInfo", typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument runtime_info", value=runtime_info, expected_type=type_hints["runtime_info"])
         self._values: typing.Dict[str, typing.Any] = {}
         if runtime_info is not None:
             self._values["runtime_info"] = runtime_info
@@ -141,8 +167,8 @@ class CloudArtifact(
         *,
         type: ros_cdk_assembly_schema.ArtifactType,
         dependencies: typing.Optional[typing.Sequence[builtins.str]] = None,
-        metadata: typing.Optional[typing.Mapping[builtins.str, typing.Sequence[ros_cdk_assembly_schema.MetadataEntry]]] = None,
-        properties: typing.Optional[typing.Union[ros_cdk_assembly_schema.AliyunRosStackProperties, ros_cdk_assembly_schema.TreeArtifactProperties, ros_cdk_assembly_schema.NestedCloudAssemblyProperties]] = None,
+        metadata: typing.Optional[typing.Mapping[builtins.str, typing.Sequence[typing.Union[ros_cdk_assembly_schema.MetadataEntry, typing.Dict[str, typing.Any]]]]] = None,
+        properties: typing.Optional[typing.Union[typing.Union[ros_cdk_assembly_schema.AliyunRosStackProperties, typing.Dict[str, typing.Any]], typing.Union[ros_cdk_assembly_schema.TreeArtifactProperties, typing.Dict[str, typing.Any]], typing.Union[ros_cdk_assembly_schema.NestedCloudAssemblyProperties, typing.Dict[str, typing.Any]]]] = None,
     ) -> None:
         '''
         :param assembly: -
@@ -152,6 +178,20 @@ class CloudArtifact(
         :param metadata: Associated metadata. Default: - no metadata.
         :param properties: The set of properties for this artifact (depends on type). Default: - no properties.
         '''
+        if __debug__:
+            def stub(
+                assembly: "CloudAssembly",
+                id: builtins.str,
+                *,
+                type: ros_cdk_assembly_schema.ArtifactType,
+                dependencies: typing.Optional[typing.Sequence[builtins.str]] = None,
+                metadata: typing.Optional[typing.Mapping[builtins.str, typing.Sequence[typing.Union[ros_cdk_assembly_schema.MetadataEntry, typing.Dict[str, typing.Any]]]]] = None,
+                properties: typing.Optional[typing.Union[typing.Union[ros_cdk_assembly_schema.AliyunRosStackProperties, typing.Dict[str, typing.Any]], typing.Union[ros_cdk_assembly_schema.TreeArtifactProperties, typing.Dict[str, typing.Any]], typing.Union[ros_cdk_assembly_schema.NestedCloudAssemblyProperties, typing.Dict[str, typing.Any]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument assembly", value=assembly, expected_type=type_hints["assembly"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         manifest = ros_cdk_assembly_schema.ArtifactManifest(
             type=type,
             dependencies=dependencies,
@@ -161,7 +201,7 @@ class CloudArtifact(
 
         jsii.create(self.__class__, self, [assembly, id, manifest])
 
-    @jsii.member(jsii_name="fromManifest") # type: ignore[misc]
+    @jsii.member(jsii_name="fromManifest")
     @builtins.classmethod
     def from_manifest(
         cls,
@@ -170,8 +210,8 @@ class CloudArtifact(
         *,
         type: ros_cdk_assembly_schema.ArtifactType,
         dependencies: typing.Optional[typing.Sequence[builtins.str]] = None,
-        metadata: typing.Optional[typing.Mapping[builtins.str, typing.Sequence[ros_cdk_assembly_schema.MetadataEntry]]] = None,
-        properties: typing.Optional[typing.Union[ros_cdk_assembly_schema.AliyunRosStackProperties, ros_cdk_assembly_schema.TreeArtifactProperties, ros_cdk_assembly_schema.NestedCloudAssemblyProperties]] = None,
+        metadata: typing.Optional[typing.Mapping[builtins.str, typing.Sequence[typing.Union[ros_cdk_assembly_schema.MetadataEntry, typing.Dict[str, typing.Any]]]]] = None,
+        properties: typing.Optional[typing.Union[typing.Union[ros_cdk_assembly_schema.AliyunRosStackProperties, typing.Dict[str, typing.Any]], typing.Union[ros_cdk_assembly_schema.TreeArtifactProperties, typing.Dict[str, typing.Any]], typing.Union[ros_cdk_assembly_schema.NestedCloudAssemblyProperties, typing.Dict[str, typing.Any]]]] = None,
     ) -> typing.Optional["CloudArtifact"]:
         '''Returns a subclass of ``CloudArtifact`` based on the artifact type defined in the artifact manifest.
 
@@ -184,6 +224,20 @@ class CloudArtifact(
 
         :return: the ``CloudArtifact`` that matches the artifact type or ``undefined`` if it's an artifact type that is unrecognized by this module.
         '''
+        if __debug__:
+            def stub(
+                assembly: "CloudAssembly",
+                id: builtins.str,
+                *,
+                type: ros_cdk_assembly_schema.ArtifactType,
+                dependencies: typing.Optional[typing.Sequence[builtins.str]] = None,
+                metadata: typing.Optional[typing.Mapping[builtins.str, typing.Sequence[typing.Union[ros_cdk_assembly_schema.MetadataEntry, typing.Dict[str, typing.Any]]]]] = None,
+                properties: typing.Optional[typing.Union[typing.Union[ros_cdk_assembly_schema.AliyunRosStackProperties, typing.Dict[str, typing.Any]], typing.Union[ros_cdk_assembly_schema.TreeArtifactProperties, typing.Dict[str, typing.Any]], typing.Union[ros_cdk_assembly_schema.NestedCloudAssemblyProperties, typing.Dict[str, typing.Any]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument assembly", value=assembly, expected_type=type_hints["assembly"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         artifact = ros_cdk_assembly_schema.ArtifactManifest(
             type=type,
             dependencies=dependencies,
@@ -203,31 +257,36 @@ class CloudArtifact(
 
         :return: all the metadata entries of a specific type in this artifact.
         '''
+        if __debug__:
+            def stub(type: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument type", value=type, expected_type=type_hints["type"])
         return typing.cast(typing.List["MetadataEntryResult"], jsii.invoke(self, "findMetadataByType", [type]))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="assembly")
     def assembly(self) -> "CloudAssembly":
         return typing.cast("CloudAssembly", jsii.get(self, "assembly"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="id")
     def id(self) -> builtins.str:
         return typing.cast(builtins.str, jsii.get(self, "id"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="manifest")
     def manifest(self) -> ros_cdk_assembly_schema.ArtifactManifest:
         '''The artifact's manifest.'''
         return typing.cast(ros_cdk_assembly_schema.ArtifactManifest, jsii.get(self, "manifest"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="messages")
     def messages(self) -> typing.List["SynthesisMessage"]:
         '''The set of messages extracted from the artifact's metadata.'''
         return typing.cast(typing.List["SynthesisMessage"], jsii.get(self, "messages"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="dependencies")
     def dependencies(self) -> typing.Optional[typing.List["CloudArtifact"]]:
         '''Returns all the artifacts that this artifact depends on.'''
@@ -245,6 +304,11 @@ class CloudAssembly(
 
         :param directory: The root directory of the assembly.
         '''
+        if __debug__:
+            def stub(directory: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument directory", value=directory, expected_type=type_hints["directory"])
         jsii.create(self.__class__, self, [directory])
 
     @jsii.member(jsii_name="getNestedAssembly")
@@ -253,6 +317,11 @@ class CloudAssembly(
 
         :param artifact_id: The artifact ID of the nested assembly.
         '''
+        if __debug__:
+            def stub(artifact_id: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument artifact_id", value=artifact_id, expected_type=type_hints["artifact_id"])
         return typing.cast("CloudAssembly", jsii.invoke(self, "getNestedAssembly", [artifact_id]))
 
     @jsii.member(jsii_name="getNestedAssemblyArtifact")
@@ -264,6 +333,11 @@ class CloudAssembly(
 
         :param artifact_id: The artifact ID of the nested assembly.
         '''
+        if __debug__:
+            def stub(artifact_id: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument artifact_id", value=artifact_id, expected_type=type_hints["artifact_id"])
         return typing.cast("NestedCloudAssemblyArtifact", jsii.invoke(self, "getNestedAssemblyArtifact", [artifact_id]))
 
     @jsii.member(jsii_name="getStack")
@@ -274,6 +348,11 @@ class CloudAssembly(
 
         :param stack_name: -
         '''
+        if __debug__:
+            def stub(stack_name: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument stack_name", value=stack_name, expected_type=type_hints["stack_name"])
         return typing.cast("RosStackArtifact", jsii.invoke(self, "getStack", [stack_name]))
 
     @jsii.member(jsii_name="getStackArtifact")
@@ -286,6 +365,11 @@ class CloudAssembly(
 
         :param artifact_id: -
         '''
+        if __debug__:
+            def stub(artifact_id: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument artifact_id", value=artifact_id, expected_type=type_hints["artifact_id"])
         return typing.cast("RosStackArtifact", jsii.invoke(self, "getStackArtifact", [artifact_id]))
 
     @jsii.member(jsii_name="getStackByName")
@@ -302,6 +386,11 @@ class CloudAssembly(
 
         :param stack_name: -
         '''
+        if __debug__:
+            def stub(stack_name: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument stack_name", value=stack_name, expected_type=type_hints["stack_name"])
         return typing.cast("RosStackArtifact", jsii.invoke(self, "getStackByName", [stack_name]))
 
     @jsii.member(jsii_name="tree")
@@ -322,33 +411,38 @@ class CloudAssembly(
 
         :param id: -
         '''
+        if __debug__:
+            def stub(id: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         return typing.cast(typing.Optional[CloudArtifact], jsii.invoke(self, "tryGetArtifact", [id]))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="artifacts")
     def artifacts(self) -> typing.List[CloudArtifact]:
         '''All artifacts included in this assembly.'''
         return typing.cast(typing.List[CloudArtifact], jsii.get(self, "artifacts"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="directory")
     def directory(self) -> builtins.str:
         '''The root directory of the cloud assembly.'''
         return typing.cast(builtins.str, jsii.get(self, "directory"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="manifest")
     def manifest(self) -> ros_cdk_assembly_schema.AssemblyManifest:
         '''The raw assembly manifest.'''
         return typing.cast(ros_cdk_assembly_schema.AssemblyManifest, jsii.get(self, "manifest"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="runtime")
     def runtime(self) -> ros_cdk_assembly_schema.RuntimeInfo:
         '''Runtime information such as module versions used to synthesize this assembly.'''
         return typing.cast(ros_cdk_assembly_schema.RuntimeInfo, jsii.get(self, "runtime"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="stacks")
     def stacks(self) -> typing.List["RosStackArtifact"]:
         '''
@@ -356,7 +450,7 @@ class CloudAssembly(
         '''
         return typing.cast(typing.List["RosStackArtifact"], jsii.get(self, "stacks"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="version")
     def version(self) -> builtins.str:
         '''The schema version of the assembly manifest.'''
@@ -374,6 +468,11 @@ class CloudAssemblyBuilder(
 
         :param outdir: The output directory, uses temporary directory if undefined.
         '''
+        if __debug__:
+            def stub(outdir: typing.Optional[builtins.str] = None) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument outdir", value=outdir, expected_type=type_hints["outdir"])
         jsii.create(self.__class__, self, [outdir])
 
     @jsii.member(jsii_name="addArtifact")
@@ -383,8 +482,8 @@ class CloudAssemblyBuilder(
         *,
         type: ros_cdk_assembly_schema.ArtifactType,
         dependencies: typing.Optional[typing.Sequence[builtins.str]] = None,
-        metadata: typing.Optional[typing.Mapping[builtins.str, typing.Sequence[ros_cdk_assembly_schema.MetadataEntry]]] = None,
-        properties: typing.Optional[typing.Union[ros_cdk_assembly_schema.AliyunRosStackProperties, ros_cdk_assembly_schema.TreeArtifactProperties, ros_cdk_assembly_schema.NestedCloudAssemblyProperties]] = None,
+        metadata: typing.Optional[typing.Mapping[builtins.str, typing.Sequence[typing.Union[ros_cdk_assembly_schema.MetadataEntry, typing.Dict[str, typing.Any]]]]] = None,
+        properties: typing.Optional[typing.Union[typing.Union[ros_cdk_assembly_schema.AliyunRosStackProperties, typing.Dict[str, typing.Any]], typing.Union[ros_cdk_assembly_schema.TreeArtifactProperties, typing.Dict[str, typing.Any]], typing.Union[ros_cdk_assembly_schema.NestedCloudAssemblyProperties, typing.Dict[str, typing.Any]]]] = None,
     ) -> None:
         '''Adds an artifact into the cloud assembly.
 
@@ -394,6 +493,18 @@ class CloudAssemblyBuilder(
         :param metadata: Associated metadata. Default: - no metadata.
         :param properties: The set of properties for this artifact (depends on type). Default: - no properties.
         '''
+        if __debug__:
+            def stub(
+                id: builtins.str,
+                *,
+                type: ros_cdk_assembly_schema.ArtifactType,
+                dependencies: typing.Optional[typing.Sequence[builtins.str]] = None,
+                metadata: typing.Optional[typing.Mapping[builtins.str, typing.Sequence[typing.Union[ros_cdk_assembly_schema.MetadataEntry, typing.Dict[str, typing.Any]]]]] = None,
+                properties: typing.Optional[typing.Union[typing.Union[ros_cdk_assembly_schema.AliyunRosStackProperties, typing.Dict[str, typing.Any]], typing.Union[ros_cdk_assembly_schema.TreeArtifactProperties, typing.Dict[str, typing.Any]], typing.Union[ros_cdk_assembly_schema.NestedCloudAssemblyProperties, typing.Dict[str, typing.Any]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         manifest = ros_cdk_assembly_schema.ArtifactManifest(
             type=type,
             dependencies=dependencies,
@@ -408,7 +519,7 @@ class CloudAssemblyBuilder(
         self,
         *,
         key: builtins.str,
-        props: typing.Union[ros_cdk_assembly_schema.AmiContextQuery, ros_cdk_assembly_schema.AvailabilityZonesContextQuery, ros_cdk_assembly_schema.HostedZoneContextQuery, ros_cdk_assembly_schema.SSMParameterContextQuery, ros_cdk_assembly_schema.VpcContextQuery, ros_cdk_assembly_schema.EndpointServiceAvailabilityZonesContextQuery],
+        props: typing.Union[typing.Union[ros_cdk_assembly_schema.AmiContextQuery, typing.Dict[str, typing.Any]], typing.Union[ros_cdk_assembly_schema.AvailabilityZonesContextQuery, typing.Dict[str, typing.Any]], typing.Union[ros_cdk_assembly_schema.HostedZoneContextQuery, typing.Dict[str, typing.Any]], typing.Union[ros_cdk_assembly_schema.SSMParameterContextQuery, typing.Dict[str, typing.Any]], typing.Union[ros_cdk_assembly_schema.VpcContextQuery, typing.Dict[str, typing.Any]], typing.Union[ros_cdk_assembly_schema.EndpointServiceAvailabilityZonesContextQuery, typing.Dict[str, typing.Any]]],
         provider: ros_cdk_assembly_schema.ContextProvider,
     ) -> None:
         '''Reports that some context is missing in order for this cloud assembly to be fully synthesized.
@@ -427,7 +538,7 @@ class CloudAssemblyBuilder(
     def build_assembly(
         self,
         *,
-        runtime_info: typing.Optional["RuntimeInfo"] = None,
+        runtime_info: typing.Optional[typing.Union["RuntimeInfo", typing.Dict[str, typing.Any]]] = None,
     ) -> CloudAssembly:
         '''Finalizes the cloud assembly into the output directory returns a 'CloudAssembly' object that can be used to inspect the assembly.
 
@@ -448,9 +559,15 @@ class CloudAssemblyBuilder(
         :param artifact_id: -
         :param display_name: -
         '''
+        if __debug__:
+            def stub(artifact_id: builtins.str, display_name: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument artifact_id", value=artifact_id, expected_type=type_hints["artifact_id"])
+            check_type(argname="argument display_name", value=display_name, expected_type=type_hints["display_name"])
         return typing.cast("CloudAssemblyBuilder", jsii.invoke(self, "createNestedAssembly", [artifact_id, display_name]))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="outdir")
     def outdir(self) -> builtins.str:
         '''The root directory of the resulting cloud assembly.'''
@@ -467,7 +584,7 @@ class MetadataEntry(ros_cdk_assembly_schema.MetadataEntry):
         self,
         *,
         type: builtins.str,
-        data: typing.Optional[typing.Union[builtins.str, typing.Sequence[ros_cdk_assembly_schema.Tag]]] = None,
+        data: typing.Optional[typing.Union[builtins.str, typing.Sequence[typing.Union[ros_cdk_assembly_schema.Tag, typing.Dict[str, typing.Any]]]]] = None,
         trace: typing.Optional[typing.Sequence[builtins.str]] = None,
     ) -> None:
         '''(deprecated) Backwards compatibility for when 'MetadataEntry' was defined here.
@@ -484,6 +601,18 @@ class MetadataEntry(ros_cdk_assembly_schema.MetadataEntry):
         :stability: deprecated
         :alicloud: /ros-cdk-core library.
         '''
+        if __debug__:
+            def stub(
+                *,
+                type: builtins.str,
+                data: typing.Optional[typing.Union[builtins.str, typing.Sequence[typing.Union[ros_cdk_assembly_schema.Tag, typing.Dict[str, typing.Any]]]]] = None,
+                trace: typing.Optional[typing.Sequence[builtins.str]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument type", value=type, expected_type=type_hints["type"])
+            check_type(argname="argument data", value=data, expected_type=type_hints["data"])
+            check_type(argname="argument trace", value=trace, expected_type=type_hints["trace"])
         self._values: typing.Dict[str, typing.Any] = {
             "type": type,
         }
@@ -541,7 +670,7 @@ class MetadataEntryResult(ros_cdk_assembly_schema.MetadataEntry):
         self,
         *,
         type: builtins.str,
-        data: typing.Optional[typing.Union[builtins.str, typing.Sequence[ros_cdk_assembly_schema.Tag]]] = None,
+        data: typing.Optional[typing.Union[builtins.str, typing.Sequence[typing.Union[ros_cdk_assembly_schema.Tag, typing.Dict[str, typing.Any]]]]] = None,
         trace: typing.Optional[typing.Sequence[builtins.str]] = None,
         path: builtins.str,
     ) -> None:
@@ -551,6 +680,20 @@ class MetadataEntryResult(ros_cdk_assembly_schema.MetadataEntry):
         :param trace: A stack trace for when the entry was created. Default: - no trace.
         :param path: The path in which this entry was defined.
         '''
+        if __debug__:
+            def stub(
+                *,
+                type: builtins.str,
+                data: typing.Optional[typing.Union[builtins.str, typing.Sequence[typing.Union[ros_cdk_assembly_schema.Tag, typing.Dict[str, typing.Any]]]]] = None,
+                trace: typing.Optional[typing.Sequence[builtins.str]] = None,
+                path: builtins.str,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument type", value=type, expected_type=type_hints["type"])
+            check_type(argname="argument data", value=data, expected_type=type_hints["data"])
+            check_type(argname="argument trace", value=trace, expected_type=type_hints["trace"])
+            check_type(argname="argument path", value=path, expected_type=type_hints["path"])
         self._values: typing.Dict[str, typing.Any] = {
             "type": type,
             "path": path,
@@ -633,6 +776,18 @@ class MissingContext:
         :stability: deprecated
         :alicloud: /ros-cdk-core library.
         '''
+        if __debug__:
+            def stub(
+                *,
+                key: builtins.str,
+                props: typing.Mapping[builtins.str, typing.Any],
+                provider: builtins.str,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument key", value=key, expected_type=type_hints["key"])
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
+            check_type(argname="argument provider", value=provider, expected_type=type_hints["provider"])
         self._values: typing.Dict[str, typing.Any] = {
             "key": key,
             "props": props,
@@ -701,8 +856,8 @@ class NestedCloudAssemblyArtifact(
         *,
         type: ros_cdk_assembly_schema.ArtifactType,
         dependencies: typing.Optional[typing.Sequence[builtins.str]] = None,
-        metadata: typing.Optional[typing.Mapping[builtins.str, typing.Sequence[ros_cdk_assembly_schema.MetadataEntry]]] = None,
-        properties: typing.Optional[typing.Union[ros_cdk_assembly_schema.AliyunRosStackProperties, ros_cdk_assembly_schema.TreeArtifactProperties, ros_cdk_assembly_schema.NestedCloudAssemblyProperties]] = None,
+        metadata: typing.Optional[typing.Mapping[builtins.str, typing.Sequence[typing.Union[ros_cdk_assembly_schema.MetadataEntry, typing.Dict[str, typing.Any]]]]] = None,
+        properties: typing.Optional[typing.Union[typing.Union[ros_cdk_assembly_schema.AliyunRosStackProperties, typing.Dict[str, typing.Any]], typing.Union[ros_cdk_assembly_schema.TreeArtifactProperties, typing.Dict[str, typing.Any]], typing.Union[ros_cdk_assembly_schema.NestedCloudAssemblyProperties, typing.Dict[str, typing.Any]]]] = None,
     ) -> None:
         '''
         :param assembly: -
@@ -712,6 +867,20 @@ class NestedCloudAssemblyArtifact(
         :param metadata: Associated metadata. Default: - no metadata.
         :param properties: The set of properties for this artifact (depends on type). Default: - no properties.
         '''
+        if __debug__:
+            def stub(
+                assembly: CloudAssembly,
+                name: builtins.str,
+                *,
+                type: ros_cdk_assembly_schema.ArtifactType,
+                dependencies: typing.Optional[typing.Sequence[builtins.str]] = None,
+                metadata: typing.Optional[typing.Mapping[builtins.str, typing.Sequence[typing.Union[ros_cdk_assembly_schema.MetadataEntry, typing.Dict[str, typing.Any]]]]] = None,
+                properties: typing.Optional[typing.Union[typing.Union[ros_cdk_assembly_schema.AliyunRosStackProperties, typing.Dict[str, typing.Any]], typing.Union[ros_cdk_assembly_schema.TreeArtifactProperties, typing.Dict[str, typing.Any]], typing.Union[ros_cdk_assembly_schema.NestedCloudAssemblyProperties, typing.Dict[str, typing.Any]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument assembly", value=assembly, expected_type=type_hints["assembly"])
+            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
         artifact = ros_cdk_assembly_schema.ArtifactManifest(
             type=type,
             dependencies=dependencies,
@@ -721,25 +890,25 @@ class NestedCloudAssemblyArtifact(
 
         jsii.create(self.__class__, self, [assembly, name, artifact])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="directoryName")
     def directory_name(self) -> builtins.str:
         '''The relative directory name of the asset manifest.'''
         return typing.cast(builtins.str, jsii.get(self, "directoryName"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="displayName")
     def display_name(self) -> builtins.str:
         '''Display name.'''
         return typing.cast(builtins.str, jsii.get(self, "displayName"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="fullPath")
     def full_path(self) -> builtins.str:
         '''Full path to the nested assembly directory.'''
         return typing.cast(builtins.str, jsii.get(self, "fullPath"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="nestedAssembly")
     def nested_assembly(self) -> CloudAssembly:
         '''The nested Assembly.'''
@@ -758,8 +927,8 @@ class RosStackArtifact(
         *,
         type: ros_cdk_assembly_schema.ArtifactType,
         dependencies: typing.Optional[typing.Sequence[builtins.str]] = None,
-        metadata: typing.Optional[typing.Mapping[builtins.str, typing.Sequence[ros_cdk_assembly_schema.MetadataEntry]]] = None,
-        properties: typing.Optional[typing.Union[ros_cdk_assembly_schema.AliyunRosStackProperties, ros_cdk_assembly_schema.TreeArtifactProperties, ros_cdk_assembly_schema.NestedCloudAssemblyProperties]] = None,
+        metadata: typing.Optional[typing.Mapping[builtins.str, typing.Sequence[typing.Union[ros_cdk_assembly_schema.MetadataEntry, typing.Dict[str, typing.Any]]]]] = None,
+        properties: typing.Optional[typing.Union[typing.Union[ros_cdk_assembly_schema.AliyunRosStackProperties, typing.Dict[str, typing.Any]], typing.Union[ros_cdk_assembly_schema.TreeArtifactProperties, typing.Dict[str, typing.Any]], typing.Union[ros_cdk_assembly_schema.NestedCloudAssemblyProperties, typing.Dict[str, typing.Any]]]] = None,
     ) -> None:
         '''
         :param assembly: -
@@ -769,6 +938,20 @@ class RosStackArtifact(
         :param metadata: Associated metadata. Default: - no metadata.
         :param properties: The set of properties for this artifact (depends on type). Default: - no properties.
         '''
+        if __debug__:
+            def stub(
+                assembly: CloudAssembly,
+                artifact_id: builtins.str,
+                *,
+                type: ros_cdk_assembly_schema.ArtifactType,
+                dependencies: typing.Optional[typing.Sequence[builtins.str]] = None,
+                metadata: typing.Optional[typing.Mapping[builtins.str, typing.Sequence[typing.Union[ros_cdk_assembly_schema.MetadataEntry, typing.Dict[str, typing.Any]]]]] = None,
+                properties: typing.Optional[typing.Union[typing.Union[ros_cdk_assembly_schema.AliyunRosStackProperties, typing.Dict[str, typing.Any]], typing.Union[ros_cdk_assembly_schema.TreeArtifactProperties, typing.Dict[str, typing.Any]], typing.Union[ros_cdk_assembly_schema.NestedCloudAssemblyProperties, typing.Dict[str, typing.Any]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument assembly", value=assembly, expected_type=type_hints["assembly"])
+            check_type(argname="argument artifact_id", value=artifact_id, expected_type=type_hints["artifact_id"])
         artifact = ros_cdk_assembly_schema.ArtifactManifest(
             type=type,
             dependencies=dependencies,
@@ -778,7 +961,7 @@ class RosStackArtifact(
 
         jsii.create(self.__class__, self, [assembly, artifact_id, artifact])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="displayName")
     def display_name(self) -> builtins.str:
         '''A string that represents this stack.
@@ -789,7 +972,7 @@ class RosStackArtifact(
         '''
         return typing.cast(builtins.str, jsii.get(self, "displayName"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="name")
     def name(self) -> builtins.str:
         '''(deprecated) The physical name of this stack.
@@ -800,36 +983,36 @@ class RosStackArtifact(
         '''
         return typing.cast(builtins.str, jsii.get(self, "name"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="originalName")
     def original_name(self) -> builtins.str:
         '''The original name as defined in the CDK app.'''
         return typing.cast(builtins.str, jsii.get(self, "originalName"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="parameters")
     def parameters(self) -> typing.Mapping[builtins.str, builtins.str]:
         '''ROS parameters to pass to the stack.'''
         return typing.cast(typing.Mapping[builtins.str, builtins.str], jsii.get(self, "parameters"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="stackName")
     def stack_name(self) -> builtins.str:
         '''The physical name of this stack.'''
         return typing.cast(builtins.str, jsii.get(self, "stackName"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="tags")
     def tags(self) -> typing.Any:
         return typing.cast(typing.Any, jsii.get(self, "tags"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="template")
     def template(self) -> typing.Any:
         '''The ROS template for this stack.'''
         return typing.cast(typing.Any, jsii.get(self, "template"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="templateFile")
     def template_file(self) -> builtins.str:
         '''The file name of the template.'''
@@ -859,6 +1042,11 @@ class RuntimeInfo(ros_cdk_assembly_schema.RuntimeInfo):
         :stability: deprecated
         :alicloud: /ros-cdk-core library.
         '''
+        if __debug__:
+            def stub(*, libraries: typing.Mapping[builtins.str, builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument libraries", value=libraries, expected_type=type_hints["libraries"])
         self._values: typing.Dict[str, typing.Any] = {
             "libraries": libraries,
         }
@@ -891,7 +1079,7 @@ class SynthesisMessage:
     def __init__(
         self,
         *,
-        entry: ros_cdk_assembly_schema.MetadataEntry,
+        entry: typing.Union[ros_cdk_assembly_schema.MetadataEntry, typing.Dict[str, typing.Any]],
         id: builtins.str,
         level: "SynthesisMessageLevel",
     ) -> None:
@@ -902,6 +1090,18 @@ class SynthesisMessage:
         '''
         if isinstance(entry, dict):
             entry = ros_cdk_assembly_schema.MetadataEntry(**entry)
+        if __debug__:
+            def stub(
+                *,
+                entry: typing.Union[ros_cdk_assembly_schema.MetadataEntry, typing.Dict[str, typing.Any]],
+                id: builtins.str,
+                level: "SynthesisMessageLevel",
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument entry", value=entry, expected_type=type_hints["entry"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
+            check_type(argname="argument level", value=level, expected_type=type_hints["level"])
         self._values: typing.Dict[str, typing.Any] = {
             "entry": entry,
             "id": id,
@@ -957,8 +1157,8 @@ class TreeCloudArtifact(
         *,
         type: ros_cdk_assembly_schema.ArtifactType,
         dependencies: typing.Optional[typing.Sequence[builtins.str]] = None,
-        metadata: typing.Optional[typing.Mapping[builtins.str, typing.Sequence[ros_cdk_assembly_schema.MetadataEntry]]] = None,
-        properties: typing.Optional[typing.Union[ros_cdk_assembly_schema.AliyunRosStackProperties, ros_cdk_assembly_schema.TreeArtifactProperties, ros_cdk_assembly_schema.NestedCloudAssemblyProperties]] = None,
+        metadata: typing.Optional[typing.Mapping[builtins.str, typing.Sequence[typing.Union[ros_cdk_assembly_schema.MetadataEntry, typing.Dict[str, typing.Any]]]]] = None,
+        properties: typing.Optional[typing.Union[typing.Union[ros_cdk_assembly_schema.AliyunRosStackProperties, typing.Dict[str, typing.Any]], typing.Union[ros_cdk_assembly_schema.TreeArtifactProperties, typing.Dict[str, typing.Any]], typing.Union[ros_cdk_assembly_schema.NestedCloudAssemblyProperties, typing.Dict[str, typing.Any]]]] = None,
     ) -> None:
         '''
         :param assembly: -
@@ -968,6 +1168,20 @@ class TreeCloudArtifact(
         :param metadata: Associated metadata. Default: - no metadata.
         :param properties: The set of properties for this artifact (depends on type). Default: - no properties.
         '''
+        if __debug__:
+            def stub(
+                assembly: CloudAssembly,
+                name: builtins.str,
+                *,
+                type: ros_cdk_assembly_schema.ArtifactType,
+                dependencies: typing.Optional[typing.Sequence[builtins.str]] = None,
+                metadata: typing.Optional[typing.Mapping[builtins.str, typing.Sequence[typing.Union[ros_cdk_assembly_schema.MetadataEntry, typing.Dict[str, typing.Any]]]]] = None,
+                properties: typing.Optional[typing.Union[typing.Union[ros_cdk_assembly_schema.AliyunRosStackProperties, typing.Dict[str, typing.Any]], typing.Union[ros_cdk_assembly_schema.TreeArtifactProperties, typing.Dict[str, typing.Any]], typing.Union[ros_cdk_assembly_schema.NestedCloudAssemblyProperties, typing.Dict[str, typing.Any]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
+            check_type(argname="argument assembly", value=assembly, expected_type=type_hints["assembly"])
+            check_type(argname="argument name", value=name, expected_type=type_hints["name"])
         artifact = ros_cdk_assembly_schema.ArtifactManifest(
             type=type,
             dependencies=dependencies,
@@ -977,7 +1191,7 @@ class TreeCloudArtifact(
 
         jsii.create(self.__class__, self, [assembly, name, artifact])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="file")
     def file(self) -> builtins.str:
         return typing.cast(builtins.str, jsii.get(self, "file"))
