@@ -8,10 +8,15 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 import ros_cdk_assembly_schema._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@alicloud/ros-cdk-cxapi", "1.0.7", __name__[0:-6], "ros-cdk-cxapi@1.0.7.jsii.tgz"
+    "@alicloud/ros-cdk-cxapi",
+    "1.0.12",
+    __name__[0:-6],
+    "ros-cdk-cxapi@1.0.12.jsii.tgz",
 )
 
 __all__ = [
